##################################################
##################################################
#
# REPLICATION FILES FOR "STATE NETWORKS AND INTRA-ETHNIC 
# GROUP VARIATION IN THE 2011 SYRIAN UPRISING," 
# COMPARATIVE POLITICAL STUDIES
#
# KEVIN MAZUR, kevin.a.mazur@gmail.com
#
##################################################
##################################################

#SET WORKING DRIVE
setwd("XXX")

require(xtable)
library(stargazer)
library(MASS)


##################################################
#TABLE 1
##################################################

ps <- read.csv("public_services.csv")
ps$popwt <- ps$govwrk * ps$tot_pop
ps$wpw <- ps$pgwater * ps$tot_pop
ps$epw <- ps$pgelec * ps$tot_pop
ps$spw <- ps$pgsanit * ps$tot_pop

psg <- ps[!is.na(ps$govwrk),]
psw <- ps[!is.na(ps$pgwater),]
pse <- ps[!is.na(ps$pgelec),]
pss <- ps[!is.na(ps$pgsanit),]

pubempl <- c(round(tapply(psg$popwt,psg$emaj5cat,sum)*100/tapply(psg$tot_pop,psg$emaj5cat,sum), digits=0),
round(tapply(psg$popwt,psg$psz,sum)*100/tapply(psg$tot_pop,psg$psz,sum), digits=0))
water <- c(round(tapply(psw$wpw,psw$emaj5cat,sum)*100/tapply(psw$tot_pop,psw$emaj5cat,sum), digits=0),
round(tapply(psw$wpw,psw$psz,sum)*100/tapply(psw$tot_pop,psw$psz,sum), digits=0))
elec <- c(round(tapply(pse$epw,pse$emaj5cat,sum)*100/tapply(pse$tot_pop,pse$emaj5cat,sum), digits=0), round(tapply(pse$epw,pse$psz,sum)*100/tapply(pse$tot_pop,pse$psz,sum), digits=0))
sanit <- c(round(tapply(pss$spw,pss$emaj5cat,sum)*100/tapply(pss$tot_pop,pss$emaj5cat,sum), digits=0), 
round(tapply(pss$spw,pss$psz,sum)*100/tapply(pss$tot_pop,pss$psz,sum), digits=0))
nobs <- c(table(ps$emaj5cat),table(ps$psz))
pctpop <- c(round(tapply(ps$tot_pop,ps$emaj5cat,sum)*100/sum(ps$tot_pop), digits=0),
round(tapply(ps$tot_pop,ps$psz,sum)*100/sum(ps$tot_pop),digits=0))
require(xtable)
xtable(data.frame(pubempl,water,elec,sanit,nobs,pctpop), digits=0)



##################################################
#TABLE 2
##################################################

db <- read.csv("event_db.csv")

dbx <- db[db$time<90,]
p1t <- c(sum(dbx$ch_pcfl) + sum(dbx$ch_sviol),
sum(dbx$st_crctrl), sum(dbx$st_tactrl), 
sum(dbx$st_destroy), 
sum(dbx$al_nviol==1 | dbx$al_viol==1),
sum(dbx$st_confront==1 | dbx$ch_cviol==1))
p1t[7] <- sum(p1t)

dbx <- db[db$time>89 & db$time<243,]
p2t <- c(sum(dbx$ch_pcfl) + sum(dbx$ch_sviol),
sum(dbx$st_crctrl), sum(dbx$st_tactrl),
sum(dbx$st_destroy), 
sum(dbx$al_nviol==1 | dbx$al_viol==1),
sum(dbx$st_confront==1 | dbx$ch_cviol==1))
p2t[7] <- sum(p2t)

dbx <- db[db$time>242 & db$time<335,]
p3t <- c(sum(dbx$ch_pcfl) + sum(dbx$ch_sviol),
sum(dbx$st_crctrl), sum(dbx$st_tactrl),
sum(dbx$st_destroy), 
sum(dbx$al_nviol==1 | dbx$al_viol==1),
sum(dbx$st_confront==1 | dbx$ch_cviol==1))
p3t[7] <- sum(p3t)

dbx <- db[db$time<335,]
p123t <- c(sum(dbx$ch_pcfl) + sum(dbx$ch_sviol),
sum(dbx$st_crctrl), sum(dbx$st_tactrl),
sum(dbx$st_destroy), 
sum(dbx$al_nviol==1 | dbx$al_viol==1),
sum(dbx$st_confront==1 | dbx$ch_cviol==1))
p123t[7] <- sum(p123t)

xx <- data.frame(p1=p1t,p2=p2t,p3=p3t,total=p123t)
row.names(xx) <- c("challenger", "regime crowd control", "regime tactical control", "regime town destruction", "ally","clash", "total")

xtable(xx)

##################################################
#TABLE 3
##################################################

chper <- read.csv("chall_byper.csv")

ethc <- data.frame(p1=100*(tapply(chper$cncs_p1,chper$emaj5cat, sum)/sum(chper$cncs_p1)),
p2=100*(tapply(chper$cncs_p2,chper$emaj5cat, sum)/sum(chper$cncs_p2)),
p3=100*(tapply(chper$cncs_p3,chper$emaj5cat, sum)/sum(chper$cncs_p3)),
tot=100*(tapply(chper$cncs_p123,chper$emaj5cat, sum)/sum(chper$cncs_p123)),
poppct=100*(tapply(chper$tot_pop, chper$emaj5cat, sum)/sum(chper$tot_pop)),
ntown=as.numeric(table(chper$emaj5cat)))

popz <- data.frame(p1=100*(tapply(chper$cncs_p1,chper$psz, sum)/sum(chper$cncs_p1)),
p2=100*(tapply(chper$cncs_p2,chper$psz, sum)/sum(chper$cncs_p2)),
p3=100*(tapply(chper$cncs_p3,chper$psz, sum)/sum(chper$cncs_p3)),
tot=100*(tapply(chper$cncs_p123,chper$psz, sum)/sum(chper$cncs_p123)),
poppct=100*(tapply(chper$tot_pop, chper$psz, sum)/sum(chper$tot_pop)),
ntown=as.numeric(table(chper$psz)))

table3 <- rbind(ethc,popz,"totalcount"=c(sum(p1$cncs),sum(p2$cncs),sum(p3$cncs), sum(p123$cncs)), "totalpct"=c(100*sum(p1$cncs)/sum(p123$cncs), 100*sum(p2$cncs)/sum(p123$cncs), 100*sum(p3$cncs)/sum(p123$cncs),0))
xtable(table3, digits=0)

##################################################
#TABLE 4
##################################################

ch <- read.csv("chall_count_wcovars.csv")
t1 <- glm.nb(cncs_p12 ~ badawibin +  kurdbin +  alombin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch)
t2 <- glm.nb(cncs_p12 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish",])
t3 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
t4 <- glm.nb(cncs_p123 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish",])
t5 <- glm.nb(cncs_p3 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish",])
stargazer(t1,t2,t3,t4,t5)


###################
#APPENDIX TABLE A1
####################
#encirc, unempl, birth rate, terrain rugg (spec 2-5)
a1s2 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + n10_al, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a1s3 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ l3_anysec + logdistcap + asmixl4 + totunempl, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a1s4 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol +  l3_anysec + logdistcap + asmixl4 + adultillit, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a1s5 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + logdistcap + asmixl4 + rugg_s, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a1s6 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[ch$asmixl4==1 | ch$eth5_recode =="sunnifam" | ch$eth5_recode =="badawi",]) 
a1s7 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4 + nld0905, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a1s8 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4 + nld0907, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a1s9 <- glm.nb(cncs_p12 ~ govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4 + rain200, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
stargazer(t3, a1s2, a1s3, a1s4, a1s5, a1s6, a1s7, a1s8, a1s9)


####################
#APPENDIX TABLE A2
####################

a2s2 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + pgelec + asmixl4, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a2s3 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + pgsanit + asmixl4, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
a2s4<- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + pgwater + asmixl4, data=ch[ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi",])
stargazer(t3,a2s2,a2s3,a2s4)


####################
#APPENDIX TABLE A3
####################
a3s1 <- glm.nb(cncs_p12 ~ badawibin +  kurdbin +  alombin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[ch$tot_pop>1000,])
a3s6 <- glm.nb(cncs_p12 ~ badawibin +  kurdbin +  alombin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[ch$tot_pop>1000 & ch$tot_pop<100000,])
a3s2 <- glm.nb(cncs_p12 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish") & ch$tot_pop>1000,])
a3s7 <- glm.nb(cncs_p12 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish") & ch$tot_pop>1000 & ch$tot_pop<100000,])
a3s3 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi") & ch$tot_pop>1000,])
a3s8 <- glm.nb(cncs_p12 ~ badawibin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi") & ch$tot_pop>1000 & ch$tot_pop<100000,])
a3s4 <- glm.nb(cncs_p123 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish") & ch$tot_pop>1000,])
a3s9 <- glm.nb(cncs_p123 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish") & ch$tot_pop>1000 & ch$tot_pop<100000,])
a3s5 <- glm.nb(cncs_p3 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish") & ch$tot_pop>1000,])
a3s10 <- glm.nb(cncs_p3 ~ badawibin +  kurdbin + govwrkr + logpop + schenrol+ secplus + l3_anysec + logdistcap + asmixl4, data=ch[(ch$asmixl4==1 | ch$emaj5cat=="sunnifam" | ch$emaj5cat=="badawi" | ch$emaj5cat=="kurdish") & ch$tot_pop>1000 & ch$tot_pop<100000,])
stargazer(a3s1, a3s2, a3s3, a3s4, a3s5, a3s6, a3s7, a3s8, a3s9, a3s10)


####################
#APPENDIX TABLE A4
####################

nld <- read.csv(file="nl_det.csv")

a4s1 <- lm(d0904~logpop +govwrkr + rddens_rank + rugg_s + alawibin + ADM1_CAPIT, data=nld)
a4s2 <- lm(d0904~logpop + pgelec + pgsanit + govwrkr + rddens_rank + rugg_s + midcloccup + univedu + alawibin + badawibin + kurdbin+ ombin + ADM1_CAPIT, data= nld)
a4s3 <- lm(d0904~logpop + pgelec + pgsanit + govwrkr + rddens_rank + rugg_s + midcloccup + univedu + alawibin + badawibin + kurdbin+ ombin + l3capnol1, data= nld)
a4s4 <- lm(d0904~logpop +govwrkr + rddens_rank + rugg_s + alawibin + ADM1_CAPIT, data=nld[nld$coastbin==1,])
a4s5 <- lm(d0904~logpop + pgelec + pgsanit + govwrkr + rddens_rank + rugg_s + midcloccup + univedu + alawibin + ADM1_CAPIT, data=nld[nld$coastbin==1,])
a4s6 <- lm(d0907~logpop +govwrkr + rddens_rank + rugg_s + alawibin + ADM1_CAPIT, data= nld)
a4s7 <- lm(d0907~logpop + pgelec + pgsanit + govwrkr + rddens_rank + rugg_s + midcloccup + univedu + alawibin + badawibin + kurdbin+ ombin + ADM1_CAPIT, data= nld)
a4s8 <- lm(d0907~logpop + pgelec + pgsanit + govwrkr + rddens_rank + rugg_s + midcloccup + univedu + alawibin + badawibin + kurdbin+ ombin + l3capnol1, data= nld)
a4s9 <- lm(d0907~logpop +govwrkr + rddens_rank + rugg_s + alawibin + ADM1_CAPIT, data=nld[nld$coastbin==1,])
a4s10 <- lm(d0907~logpop + pgelec + pgsanit + govwrkr + rddens_rank + rugg_s + midcloccup + univedu + alawibin + ADM1_CAPIT, data=nld[nld$coastbin==1,])

stargazer(a4s1, a4s2, a4s3, a4s4, a4s5, a4s6, a4s7, a4s8, a4s9, a4s10)


####################
#APPENDIX TABLE A6
####################


nl <- read.csv("nl_shuh.csv")

a6s1 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + ligmean_change_0907
 + factor(gov_id)-1, family=binomial(link="logit"),data=nl)
a6s2 <- glm(sh_j12_25bin ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + ligmean_change_0907
 + factor(gov_id)-1, family=binomial(link="logit"), data=nl)
a6s3 <- glm(sh_j12_25bin ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + ligmean_change_0907, family=binomial(link="logit"), data=nl)
a6s4 <- glm(sh_j12_10bin ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + ligmean_change_0907, family=binomial(link="logit"), data=nl)
a6s5 <- glm(sh_o11_25bin ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + ligmean_change_0907, family=binomial(link="logit"), data=nl)
a6s6 <- glm(sh_o11_10bin ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + ligmean_change_0907, family=binomial(link="logit"), data=nl)
stargazer(a6s1, a6s2, a6s3, a6s4, a6s5, a6s6)


####################
#APPENDIX TABLE A7
####################

a7s2 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + d0904
 + factor(gov_id)-1, family=binomial(link="logit"),data=nl)
a7s3 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + d0905
 + factor(gov_id)-1, family=binomial(link="logit"),data=nl)
a7s4 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + d0906
 + factor(gov_id)-1, family=binomial(link="logit"),data=nl)
a7s5 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + d0907
 + factor(gov_id)-1, family=binomial(link="logit"),data=nl)
a7s6 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + d0908
 + factor(gov_id)-1, family=binomial(link="logit"),data=nl)

stargazer(a6s1, a7s2, a7s3, a7s4, a7s5, a7s6)